Package: MouseThymusAgeing
Type: Package
Title: Single-cell Transcriptomics Data of the Ageing Mouse Thymus
Version: 1.18.0
Authors@R: c(
    person("Mike", "Morgan", email="michael.morgan@abdn.ac.uk", role=c("aut", "cre")),
    person("Jeanette", "Baran-Gale", email="Jeanette.Baran-Gale@igmm.ed.ac.uk", role="aut"))
Description: 
    This package provides data access to counts matrices and meta-data for single-cell RNA sequencing data of 
    thymic epithlial cells across mouse ageing using SMARTseq2 and 10X Genommics chemistries. Access is provided 
    as a data package via ExperimentHub. It is designed to facilitate the re-use of data from Baran-Gale _et al._ 
    in a consistent format that includes relevant and informative meta-data. 
License: GPL-3
Encoding: UTF-8
biocViews: ExperimentHub, SingleCellData, ExpressionData,
        ExperimentData
Depends: SingleCellExperiment, SummarizedExperiment
Imports: ExperimentHub, methods, BiocGenerics, S4Vectors
Suggests: knitr, scuttle, rmarkdown, BiocStyle
VignetteBuilder: knitr
NeedsCompilation: no
Collate: 'getProcOrRaw.R' 'DropletMetadata.R' 'SMARTseqMetadata.R'
        'MouseDropletData.R' 'MouseSMARTseqData.R'
BugReports: https://github.com/MarioniLab/MouseThymusAgeing/issues
RoxygenNote: 7.1.1.9000
git_url: https://git.bioconductor.org/packages/MouseThymusAgeing
git_branch: RELEASE_3_22
git_last_commit: ad40f16
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-11-04
Packaged: 2025-11-04 16:32:50 UTC; biocbuild
Author: Mike Morgan [aut, cre],
  Jeanette Baran-Gale [aut]
Maintainer: Mike Morgan <michael.morgan@abdn.ac.uk>

# Generated by roxygen2: do not edit by hand

export(DropletMetadata)
export(MouseDropletData)
export(MouseSMARTseqData)
export(SMARTseqMetadata)
importClassesFrom(S4Vectors,DataFrame)
importFrom(BiocGenerics,"sizeFactors<-")
importFrom(BiocGenerics,sizeFactors)
importFrom(ExperimentHub,ExperimentHub)
importFrom(S4Vectors,List)
importFrom(SingleCellExperiment,SingleCellExperiment)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(methods,as)

#' Mouse ageing thymus SMART-seq2 single-cell RNA-sequencing data
#'
#' Obtain the processed counts for the mouse ageing thymus SMART-seq2 scRNA-seq data set.
#'
#' @param samples Integer or character vector specifying the samples for which data should be obtained.
#' If \code{NULL} (default), data are returned for all (5) samples.

#' @return
#' A \linkS4class{SingleCellExperiment} is returned containing processed data from selected samples.
#'
#' List elements are named after the corresponding sample.
#'
#' @details
#' This function downloads the data for the mouse ageing thymus droplet scRNA-seq
#' data from Baran-Gale et al. (2020).
#'
#' The dataset contains 5 different SMART-seq2 samples, split by the day of acquisition. The available samples are:
#' \code{day1, day2, day3, day4, day5}.
#'
#' In the data, poor-quality cells have already been removed based on insufficient sequencing depth, high mitochondrial
#' content, excessive proportion of expression from ERCC spike-in and ribosomal genes. Exact details can be found in the
#' methods section of Baran-Gale et al. (2020).
#'
#' The count matrix contains the raw count vectors for the cells that pass QC.
#' Size factors were computed using the \code{computeSumFactors} function from \pkg{scran}.
#' The column metadata for called cells contains:
#' \describe{
#' \item{\code{CellID}:}{Character, unique cell identifier across all samples.}
#' \item{\code{ClusterID}:}{Numeric, The cluster to which cells were assigned based on community detection on a shared-NN grpah.}
#' \item{\code{Position}:}{Character, Plate position of the index-sorted cell (384 well plate format).}
#' \item{\code{PlateID}:}{Character, A unique ID for the 384-well plate into which each cell was index-sorted.}
#' \item{\code{Column}:}{Integer, A value from 1-24 corresponding to the plate column.}
#' \item{\code{Row}:}{Character, A value from A-P corresponding to the plate row.}
#' \item{\code{SortType}:}{Character, Flow cytometry sorting group, mTEClo, mTEChi, gmTEC or cTEC.}
#' \item{\code{SortDay}:}{Integer, Day on which cells were sorted - corresponds to the sample IDs for downloading data and replicate.}
#' \item{\code{Age}:}{Character, Mouse age at the time of data acquisition.}
#' \item{\code{SubType}:}{Character, Annotation assigned to clusters.}
#' \item{\code{SizeFactor}:}{Numeric, Estimated normalized factor across all cells and experimental samples.}
#' }
#' Reduced dimension representations of the data are also available in the \code{reducedDims} slot of the SingleCellExperiment object.
#' The \code{SingleCellExperiment} object has row metadata that contains the Ensembl ID \code{ensembl_gene_id} and Gene
#' symbols \code{external_gene_name} for each gene, as well as gene chromosome, strand and both start and end positions.
#'
#' @author Mike Morgan, based on original code by Aaron Lun & Jonathan Griffiths
#' @examples
#' smart.data <- MouseSMARTseqData(samples = "day1")
#' smart.data
#'
#' @references
#' Baran-Gale J, Morgan MD, et al. (2020)
#' Ageing compromises mouse thymus function and remodels epithelial cell differentiation
#' \emph{eLife} 9:e56221.
#' @author Mike Morgan
#' @name MouseSMARTseqData
#' @rdname MouseSMARTseqData
#'
#' @export
#' @importFrom ExperimentHub ExperimentHub
#' @importFrom SingleCellExperiment SingleCellExperiment
#' @importFrom BiocGenerics sizeFactors
#' @importClassesFrom S4Vectors DataFrame
#' @importFrom methods as
MouseSMARTseqData <- function(samples=NULL){
    samp.names <- paste0("day", c(1:5))
    if(is.null(samples)){
        samples <- samp.names
    }

    versions <- list(base="1.0.0")

    if(!is.null(samples) & any(!samples %in% samp.names)){
        warning(paste0("Incorrect samples found. Should be in list:",
                       paste(samp.names, collapse=",")))
    }

    if(length(intersect(samples, samp.names)) > 0){
        MouseThymusAgeing:::.getProcOrRaw("SMARTseq", versions, samples)
    } else{
        stop(paste0("No matching samples found. Must be in list:",
                    paste(samp.names, collapse=",")))
    }
}

samp.names <- c("ZsG_1stRun1", "ZsG_1stRun2", "ZsG_2ndRun1", "ZsG_2ndRun2", "ZsG_3rdRun1", "ZsG_3rdRun2")

info <- data.frame(
    Title = sprintf("Droplet %s",
                    c(sprintf("processed counts (sample %s)", samp.names),
                      "rowData",
                      sprintf("colData (sample %s)", samp.names),
                      sprintf("size factors (sample %s)", samp.names),
                      sprintf("reduced dimensions (sample %s)", samp.names))
    ),
    Description = sprintf("%s for the mouse ageing thymus ZsGreen droplet single-cell RNA-seq dataset",
                          c(sprintf("Processed counts for sample %s", samp.names),
                            "Per-gene metadata for all samples",
                            sprintf("Per-cell metadata for sample %s", samp.names),
                            sprintf("Size factors for sample %s", samp.names),
                            sprintf("Reduced dimensions for sample %s", samp.names))
    ),
    RDataPath = c(
        file.path("MouseThymusAgeing", "Droplet", "1.0.0",
                  c(sprintf("counts-processed-%s.rds", samp.names),
                    "rowdata.rds",
                    sprintf("coldata-%s.rds", samp.names),
                    sprintf("sizefac-%s.rds", samp.names),
                    sprintf("reduced-dims-%s.rds", samp.names))
        )),
    BiocVersion="3.13",
    Genome="mm10",
    SourceType="TXT",
    SourceUrl=c(
        rep(
            c("https://content.cruk.cam.ac.uk/jmlab/thymus_data"),
            c(6 * 4 + 1))
    ),
    SourceVersion=paste(
        c(paste(samp.names, "raw_counts.mtx.gz", sep="_"),
          "genes.tsv.gz",
          rep("ZsG_meta_data.tsv.gz", 6),
          rep("sizefactors.tsv.gz", 6),
          rep("ZsG_PCs.tsv.gz", 6)
        ),
        sep=";"
    ),
    Species="Mus musculus",
    TaxonomyId="10090",
    Coordinate_1_based=TRUE,
    DataProvider="Mike Morgan",
    Maintainer="Mike Morgan <michael.morgan@cruk.cam.ac.uk>",
    RDataClass="character",
    DispatchClass="Rds",
    stringsAsFactors = FALSE
)

write.csv(file="../../extdata/metadata-Droplet.csv", info, row.names=FALSE)

#' Mouse ageing thymus droplet single-cell RNA-sequencing data
#'
#' Obtain the processed counts for the mouse ageing thymus droplet scRNA-seq data set.
#'
#' @param samples Integer or character vector specifying the samples for which data should be obtained.
#' If \code{NULL} (default), data are returned for all (6) samples.

#' @return
#' A \linkS4class{SingleCellExperiment} is returned containing processed data from selected samples.
#'
#' List elements are named after the corresponding sample.
#'
#' @details
#' This function downloads the data for the mouse ageing thymus droplet scRNA-seq
#' data from Baran-Gale et al. (2020).
#'
#' The dataset contains 6 10X Genomics samples. The available samples are:
#' \code{ZsG_1stRun1, ZsG_1stRun2, ZsG_2ndRun1, ZsG_2ndRun2, ZsG_3rdRun1, ZsG_3rdRun2}.
#'
#'
#' In the data, cell-containing libraries have already been identified in each sample
#' using the \code{emptyDrops} function from \pkg{DropletUtils}.
#' The count matrix contains the raw count vectors for the cells called from all samples in this manner.
#' Size factors were computed using the \code{computeSumFactors} function from \pkg{scran}.
#' The column metadata for called cells contains:
#' \describe{
#' \item{\code{CellID}:}{Character, unique cell identifier across all samples.}
#' \item{\code{SampID}:}{Character, Short unique identified for the experimental sample.}
#' \item{\code{Class}:}{Character, Either Singlet or Multiplet Identifies cells called as a multiplet from hash-tag demultiplexing.}
#' \item{\code{HTO}:}{Character, Hashtag oligo (HTO) character identifier, used for multiplexing experimental samples.}
#' \item{\code{Age}:}{Character, Age of mouse at the time of doxycycline treatment. Age at time of data acquisition is +4weeks.}
#' \item{\code{SortType}:}{Character, Flow cytometry sorting group, either ZsGreen+ (ZsGp) or ZsGreen- (ZsGn).}
#' \item{\code{Cluster}:}{Integer, Cluster to which cells were assigned based on using the Walktrap community detection algorithm on a k-NN graph.}
#' \item{\code{ClusterAnnot}:}{Character, Annotation assigned to cluster.}
#' \item{\code{SizeFactor}:}{Numeric, Estimated normalized factor across all cells and experimental samples.}
#' }
#' Reduced dimension representations of the data are also available in the \code{reducedDims} slot of the SingleCellExperiment object.
#' The \code{SingleCellExperiment} object has row metadata that contains the Ensembl ID \code{ensembl_gene_id} and Gene
#' symbols \code{external_gene_name} for each gene, as well as gene chromosome, strand and both start and end positions.
#'
#' @author Mike Morgan, based on original code by Aaron Lun & Jonathan Griffiths
#' @examples
#' drop.data <- MouseDropletData(samples = "ZsG_1stRun1")
#' drop.data
#'
#' @references
#' Baran-Gale J, Morgan MD, et al. (2020)
#' Ageing compromises mouse thymus function and remodels epithelial cell differentiation
#' \emph{eLife} 9:e56221.
#'
#' @author Mike Morgan
#' @name MouseDropletData
#' @rdname MouseDropletData
#' @export
#' @importFrom ExperimentHub ExperimentHub
#' @importFrom SingleCellExperiment SingleCellExperiment
#' @importFrom BiocGenerics sizeFactors
#' @importClassesFrom S4Vectors DataFrame
#' @importFrom methods as
MouseDropletData <- function(samples=NULL){
    samp.names <- c("ZsG_1stRun1", "ZsG_1stRun2", "ZsG_2ndRun1",
                    "ZsG_2ndRun2", "ZsG_3rdRun1", "ZsG_3rdRun2")
    if(is.null(samples)){
        samples <- samp.names
    }

    versions <- list(base="1.0.0")

    if(any(!samples %in% samp.names)){
        warning(paste0("Incorrect samples found. Should be in list:",
                       paste(samp.names, collapse=",")))
    }

    if(length(intersect(samples, samp.names)) > 0){
        MouseThymusAgeing:::.getProcOrRaw("Droplet", versions, samples)
    } else{
        stop(paste0("No matching samples found. Must be in list:",
                    paste(samp.names, collapse=",")))
    }
}

#' @title
#'  Sample metadata from the Baran-Gale et al. ageing mouse thymus droplet experiments
#'
#' A data frame containing mouse age and sort-type information for the
#' droplet single-cell RNA-sequencing experiment data sets
#'
#' @format A data frame containing information for each replicate sample
#'
#' The object contains:
#' \describe{
#' \item{\code{sample}:}{Character, sample IDs.}
#' \item{\code{Gender}:}{Character, gender of mouse - all female.}
#' \item{\code{HTO}:}{Character, hashtag oligo assignments.}
#' \item{\code{ncells}:}{Integer, number of cells (post-QC) per sample.}
#' }
#'
#' @examples head(DropletMetadata)
#'
#' @references
#' Baran-Gale J, Morgan MD, et al. (2020)
#' Ageing compromises mouse thymus function and remodels epithelial cell differentiation
#' \emph{eLife} 9:e56221.
#'
#' @author Mike Morgan
#' @name DropletMetadata
#' @rdname DropletMetadata
#' @export
DropletMetadata <- read.table(
    text =
        "sample,Gender,HTO,ncells
ZsG_1stRun1,female,Wk1_ZsGp,5160
ZsG_1stRun1,female,Wk4_ZsGp,3902
ZsG_1stRun1,female,Wk16_ZsGp,3798
ZsG_1stRun2,female,Wk1_ZsGp,3360
ZsG_1stRun2,female,Wk4_ZsGp,2355
ZsG_1stRun2,female,Wk16_ZsGp,4199
ZsG_2ndRun1,female,Wk1_ZsGn,2090
ZsG_2ndRun1,female,Wk1_ZsGp,1927
ZsG_2ndRun1,female,Wk4_ZsGn,1870
ZsG_2ndRun1,female,Wk4_ZsGp,2759
ZsG_2ndRun1,female,Wk16_ZsGn,668
ZsG_2ndRun1,female,Wk16_ZsGp,3060
ZsG_2ndRun2,female,Wk1_ZsGn,2004
ZsG_2ndRun2,female,Wk1_ZsGp,1893
ZsG_2ndRun2,female,Wk4_ZsGn,1830
ZsG_2ndRun2,female,Wk4_ZsGp,2721
ZsG_2ndRun2,female,Wk16_ZsGn,736
ZsG_2ndRun2,female,Wk16_ZsGp,2894
ZsG_3rdRun1,female,Wk1_ZsGn,1409
ZsG_3rdRun1,female,Wk1_ZsGp,1854
ZsG_3rdRun1,female,Wk4_ZsGn,1403
ZsG_3rdRun1,female,Wk4_ZsGp,2368
ZsG_3rdRun1,female,Wk16_ZsGn,1055
ZsG_3rdRun1,female,Wk16_ZsGp,1926
ZsG_3rdRun2,female,Wk1_ZsGn,1475
ZsG_3rdRun2,female,Wk1_ZsGp,2270
ZsG_3rdRun2,female,Wk4_ZsGn,1827
ZsG_3rdRun2,female,Wk4_ZsGp,3083
ZsG_3rdRun2,female,Wk16_ZsGn,1072
ZsG_3rdRun2,female,Wk16_ZsGp,2212",
    header = TRUE,
    sep = ",",
    stringsAsFactors = FALSE)

#' Sample metadata from the Baran-Gale et al. ageing mouse thymus
#'
#' A data frame containing mouse age and sort-type information for the
#' SMARTseq experiment data sets
#'
#' @format A data frame containing information for each replicate sample
#'
#' The object contains:
#' \describe{
#' \item{\code{sample}:}{Character, day<1:5>.}
#' \item{\code{Age}:}{Character, age of mouse cells acquired from.}
#' \item{\code{Gender}:}{Character, gender of mouse - all female.}
#' \item{\code{ncells}:}{Integer, number of cells (post-QC) per sample.}
#' }
#'
#' @examples head(SMARTseqMetadata)
#'
#' @references
#' Baran-Gale J, Morgan MD, et al. (2020)
#' Ageing compromises mouse thymus function and remodels epithelial cell
#' differentiation \emph{eLife} 9:e56221.
#'
#' @author Mike Morgan
#' @name SMARTseqMetadata
#' @rdname SMARTseqMetadata
#' @export
SMARTseqMetadata <- read.table(
    text =
        "sample,Age,Gender,ncells
day1,1wk,female,10
day1,4wk,female,19
day1,16wk,female,10
day1,32wk,female,43
day1,52wk,female,52
day2,1wk,female,153
day2,4wk,female,157
day2,16wk,female,156
day2,32wk,female,87
day2,52wk,female,108
day3,1wk,female,101
day3,4wk,female,111
day3,16wk,female,29
day3,32wk,female,148
day3,52wk,female,77
day4,1wk,female,60
day4,4wk,female,162
day4,16wk,female,49
day4,32wk,female,44
day4,52wk,female,4
day5,1wk,female,109
day5,4wk,female,150
day5,16wk,female,74
day5,32wk,female,174
day5,52wk,female,240",
    header = TRUE,
    sep = ",",
    stringsAsFactors = FALSE)

#' @importFrom ExperimentHub ExperimentHub
#' @importFrom SingleCellExperiment SingleCellExperiment
#' @importFrom BiocGenerics sizeFactors
#' @importFrom BiocGenerics sizeFactors<-
#' @importClassesFrom S4Vectors DataFrame
#' @importFrom S4Vectors List
#' @importFrom methods as
#' @importFrom SummarizedExperiment rowData
#' @importFrom SummarizedExperiment colData
#'
.getProcOrRaw <- function(dataset, version, samples){
    hub <- ExperimentHub()
    host <- file.path("MouseThymusAgeing", dataset)

    #get rowdata
    ver <- .fetch_version(version, "rowData")
    rowdata <- hub[hub$rdatapath==file.path(host, ver, "rowdata.rds")][[1]]

    # Temporary function for data extraction
    EXTRACTOR <- function(target, version_name) {
        ver <- .fetch_version(version, version_name)
        lapply(samples, function(i){
            hub[hub$rdatapath==file.path(host, ver,
                                         sprintf("%s-%s.rds", target, i))][[1]]
        })
    }

    count_list <- EXTRACTOR("counts-processed")
    assays <- list(counts=do.call(cbind, count_list))

    coldata_list <- EXTRACTOR("coldata", "colData")
    sf_list <- EXTRACTOR("sizefac", "sizefactors")
    reducedDims_list <- EXTRACTOR("reduced-dims", "reducedDims")

    # Handle data with multiple reducedDims
    reducedDims_names <- names(reducedDims_list[[1]])
    reducedDims_combined <- lapply(reducedDims_names, function(x){
        do.call(rbind, lapply(reducedDims_list, function(y) y[[x]]))
    })
    names(reducedDims_combined) <- reducedDims_names

    sce <- SingleCellExperiment(
        assays=assays,
        colData=as(do.call(rbind, coldata_list), "DataFrame"),
        reducedDims=reducedDims_combined,
        rowData=rowdata
    )
    sizeFactors(sce) <- unlist(sf_list)
    rownames(sce) <- rowData(sce)$Geneid
    colnames(sce) <- colData(sce)$CellID
    return(sce)
}

#from Aaron Lun's celldex with modification
#for consistent usage in-package, use "base" as element 1, anything
#with a different version gets an entry in version in .getProcOrRaw
#there should be in {counts,spliced,raw_counts,
#sizefactors,rowData,colData,reducedDims}
#spliced represents version for all spliced count measurements
.fetch_version <- function(version, field) {
    # change in behaviour - selecting an empty field used to return NULL
    # now returns an error
    opt <- tryCatch({
        version[[field]]
        }, warning=function(warn){
            warning(warn)
            version[[field]]
            }, 
        error=function(err){
            message("field not found in version - adding")
            NULL
            }, finally={
                
            })

    if (is.null(opt)) {
        version[[1]]
    } else {
        opt
    }
}

info <- data.frame(
    Title = sprintf("SMARTseq %s",
                    c(sprintf("processed counts (day %i)", c(1:5)),
                      "rowData",
                      sprintf("colData (day %i)", c(1:5)),
                      sprintf("size factors (day %i)", c(1:5)),
                      sprintf("reduced dimensions (day %i)", c(1:5)))
    ),
    Description = sprintf("%s for the mouse ageing thymus SMART-seq2 single-cell RNA-seq dataset",
                          c(sprintf("Processed counts for day %i", c(1:5)),
                            "Per-gene metadata for all days",
                            sprintf("Per-cell metadata for day %i", c(1:5)),
                            sprintf("Size factors for day %i", c(1:5)),
                            sprintf("Reduced dimensions for day %i", c(1:5)))
    ),
    RDataPath = c(
        file.path("MouseThymusAgeing", "SMARTseq", "1.0.0",
                  c(sprintf("counts-processed-day%i.rds", c(1:5)),
                    "rowdata.rds",
                    sprintf("coldata-day%i.rds", c(1:5)),
                    sprintf("sizefac-day%i.rds", c(1:5)),
                    sprintf("reduced-dims-day%i.rds", c(1:5)))
    )),
    BiocVersion="3.13",
    Genome="mm10",
    SourceType="TXT",
    SourceUrl=c(
        rep(
            c("https://content.cruk.cam.ac.uk/jmlab/thymus_data"),
            c(5 * 4 + 1))
    ),
    SourceVersion=paste(
        c(rep("QC_counts.tsv.gz", 5),
          "Gene_info.tsv",
          rep("meta_data.tsv.gz", 5),
          rep("size_factors.tsv.gz", 5),
          rep("reduced_dims.tsv.gz", 5)
        ),
        sep=";"
    ),
    Species="Mus musculus",
    TaxonomyId="10090",
    Coordinate_1_based=TRUE,
    DataProvider="Mike Morgan",
    Maintainer="Mike Morgan <michael.morgan@cruk.cam.ac.uk>",
    RDataClass="character",
    DispatchClass="Rds",
    stringsAsFactors = FALSE
)

write.csv(file="../../extdata/metadata-SMARTseq.csv", info, row.names=FALSE)

---
title: "Preparing mouse ageing thymus Droplet-seq data for ExperimentHub"
output:
  BiocStyle::html_document:
    toc_float: true
---

```{r style, echo=FALSE, results='hide', message=FALSE}
library(BiocStyle)
knitr::opts_chunk$set(error=FALSE, message=FALSE, warning=FALSE)
```

# Overview

The purpose of this notebook is to prepare the mouse thymus ageing single-cell transcriptome data generated using the droplet 10X Genomics 
chromium chemistry. These data are derived from a transgenic model used to lineage trace the descendant cells from $\beta-5t$ progenitors. TEC 
were FAC-sorted using the fluorescent transgene ZsG into positive (ZsG+) and negative (ZsG-) populations, as well as the principal TEC subtypes, 
cTEC and mTEC. These cells were derived from 3 independent replicates for each population (ZsG+/- cTEC & mTEC) 4 weeks after doxycycline treatment 
to induce the transgene, beginning with mice at 1, 4 and 16 weeks of age. Single-cell suspensions were generated, hashtag oligos (HTOs) were added 
to each pool of cells, with 6 samples pooled into each tube. A single tube was split into 2 wells on the 10X chromium chip, libraries were generated 
and sequenced on an Illumina NovaSeq 6000.

Thus, these data contain 6 samples, each of which contain input cells from 6 experimental samples (ZsG+/-, cTEC & mTEC, 1, 4 & 16 weeks old at 
treatment), for a total of 36 experimental samples.

# Preparing the processed data

To minimise memory pressure and maximise usability, we have provided a gzip compressed counts matrix for each of the 6 10X well samples - these 
have not been processed to remove poor-quality cells, but have been called as non-empty droplets. Borrowing from the 
`r Biocpkg("MouseGastrulationAtlas")` we also make using of caching in the `r Biocpkg("BiocFileCache")` to avoid having to constantly download 
data for subsequent analyses. There is a counts matrix for each sample

```{r}
library(BiocFileCache)
bfc <- BiocFileCache(ask=FALSE)
samp.names <- c("ZsG_1Run1", "ZsG_1Run2", "ZsG_2Run1", "ZsG_2Run2", "ZsG_3Run1", "ZsG_3Run2")

count.paths <- sapply(seq_along(samp.names), FUN=function(XP) bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                                                                      paste0("jmlab/thymus_data/", samp.names[XP],
                                                                                             "_raw_counts.mtx.gz"))))

ids.paths <- sapply(seq_along(samp.names), FUN=function(XP) bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                                                                    paste0("jmlab/thymus_data/", samp.names[XP],
                                                                                           "_colnames.tsv"))))
```

These contain the gene counts for cells that are called non-empty (detailed in manuscript). For these data to be usable we also need the gene IDs - 
these are provided as a separate table that contains the gene names - we'll add in additional information such as the chromosome, start and end position and gene length, later.

```{r}
genes.path <- bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                      "jmlab/thymus_data/genes.tsv.gz"))
```

The matrices need to be read in using the `readMM` function from the `r CRANpkg("Matrix")` package.

```{r}
library(Matrix)
counts.list <- list()
for(x in seq_along(ids.paths)){
  counts <- readMM(count.paths[x])
  ids <- read.table(ids.paths[x], sep="\t", header=TRUE, stringsAsFactors=FALSE)
  colnames(counts) <- ids[, 1]
  counts.list[[paste0(x)]] <- counts
}

thymus.counts <- do.call(cbind, counts.list)
```

The gene info and column names can be loaded in using the standard `read.table` functions. We'll pull in extra information like chromosome mapping 
location, positions, strand, etc from `r Biocpkg("biomaRt")`.

```{r}
library(biomaRt)
biomaRt.connection <- useMart("ensembl", "mmusculus_gene_ensembl")
gene.info <- read.table(genes.path, sep="\t", header=TRUE, stringsAsFactors=FALSE)

gene.df <- getBM(attributes = c("ensembl_gene_id", "external_gene_name", 
                                "chromosome_name", "start_position", "end_position",
                                "strand"),
                 filter="ensembl_gene_id",
                 values=gene.info[, 1],
                 mart=biomaRt.connection)
rownames(gene.df) <- gene.df$ensembl_gene_id
gene.df <- gene.df[gene.info[, 1], ]
head(gene.df)
```

Finally, we can download the size factors and other cell-wise meta-data, including sorting day (replicate), sort population, age, cluster 
ID as assigned in the manuscript and plate information. We can also pull in the reduced dimensional representations at this stage.

```{r}
# meta data
meta.path <- bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                     "jmlab/thymus_data/ZsG_meta_data.tsv.gz"))
meta.data <- read.table(meta.path, sep="\t", header=TRUE, stringsAsFactors=FALSE)
rownames(meta.data) <- meta.data$Sample

# harmonise the sample names
meta.data$SampID <- gsub(meta.data$CellOrigin, pattern="(st)|(nd)(rd)", replacement="")
meta.data <- meta.data[intersect(colnames(thymus.counts), meta.data$Sample), c("Sample", "CellOrigin", "Class",
                                                                               "HTO", "Age", "SortType", "Cluster")]
colnames(meta.data) <- c("CellID", "SampID", "Class", "HTO", "Age", "SortType", "Cluster")
meta.data$ClusterAnnot <- NA
meta.data$ClusterAnnot[meta.data$Cluster %in% c(1)] <- "mTEC.1"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(3)] <- "mTEC.2"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(14)] <- "mTEC.3"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(6)] <- "mTEC.4"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(20)] <- "mTEC.5"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(22)] <- "mTEC.6"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(16)] <- "mTEC.7"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(4)] <- "Intertypical.TEC.1"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(7)] <- "Intertypical.TEC.2"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(10)] <- "Intertypical.TEC.3"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(11)] <- "Intertypical.TEC.4"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(9)] <- "cTEC.1"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(13)] <- "cTEC.2"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(17)] <- "PostAire.mTEC.1"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(19)] <- "PostAire.mTEC.2"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(23)] <- "eTEC1"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(24)] <- "Prolif.TEC.1"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(12)] <- "Prolif.TEC.2"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(2)] <- "Prolif.TEC.3"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(15)] <- "Tuft.mTEC.1"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(18)] <- "Tuft.mTEC.2"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(5)] <- "Sca1.TEC.1"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(8)] <- "New.TEC.1"
meta.data$ClusterAnnot[meta.data$Cluster %in% c(21)] <- "New.TEC.2"
head(meta.data)
```


```{r}
# pca
reds.path <- bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                     "jmlab/thymus_data/ZsG_PCs.tsv.gz"))
pca.dims <- read.table(reds.path, sep="\t", header=TRUE, stringsAsFactors=FALSE)
rownames(pca.dims) <- pca.dims$Sample
pca.dims <- pca.dims[rownames(meta.data), ]
head(pca.dims)
```


```{r}
# size factors
sf.path <- bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                     "jmlab/thymus_data/sizefactors.tsv.gz"))
size.factors <- read.table(sf.path, sep="\t", header=TRUE, stringsAsFactors=FALSE)
rownames(size.factors) <- size.factors$Sample
size.factors <- size.factors[rownames(meta.data), ]
head(size.factors)
```

We will now put all of these together into a convenient `SingleCellExperiment` object.

```{r}
library(SingleCellExperiment)
thymus.sce <- SingleCellExperiment(assays=list(counts=thymus.counts[, rownames(meta.data)]),
                                   colData=meta.data, rowData=gene.df)
rownames(thymus.sce) <- gene.info[, 1]

# add the size factors
sizeFactors(thymus.sce) <- size.factors$SumFactor

reducedDim(thymus.sce, "PCA") <- as.matrix(pca.dims[, paste0("PC", 1:50)])
thymus.sce
```

We are now in the position to save all of these data. We'll do this by breaking up the `SingleCellExperiment` object into smaller, sample-wise 
objects as this will help to increase the speed of downloading. These smaller files are what get uploaded to `r Biocpkg("ExperimentHub")`.

```{r}
base <- file.path("MouseThymusAgeing", "Droplet", "1.0.0")
dir.create(base, recursive=TRUE, showWarnings=FALSE)
saveRDS(rowData(thymus.sce), file=paste0(base, "/rowdata.rds"))
for(samp in unique(thymus.sce$SampID)){
    sub <- thymus.sce[, thymus.sce$SampID == samp]
    rownames(sub) <- rownames(thymus.sce)
    saveRDS(counts(sub), 
        file=paste0(base, "/counts-processed-ZsG_", samp, ".rds"))
    saveRDS(colData(sub), 
        file=paste0(base, "/coldata-ZsG_", samp, ".rds"))
    saveRDS(sizeFactors(sub), 
        file=paste0(base, "/sizefac-ZsG_", samp, ".rds"))
    saveRDS(reducedDims(sub), 
        file=paste0(base, "/reduced-dims-ZsG_", samp, ".rds"))
}
```


# Session information

```{r}
sessionInfo()
```

---
title: "Preparing mouse ageing thymus SMART-seq data for ExperimentHub"
output:
  BiocStyle::html_document:
    toc_float: true
---

```{r style, echo=FALSE, results='hide', message=FALSE}
library(BiocStyle)
knitr::opts_chunk$set(error=FALSE, message=FALSE, warning=FALSE)
```

# Overview

The purpose of this notebook is to prepare the mouse thymus ageing single-cell transcriptome data generated using the plate-based 
SMART-seq2 chemistry. Specific thymic epithelial cell (TEC) subpopulations (mTEClo, mTEChi, cTEC & Dsg3+ mTEC) were flourescence-activated cell 
sorted (FACS) into 384-well plates containing lysis buffer, and frozen down before processing using the SMART-seq2 chemistry. Single-cells 
were sampled from mice of 5 different ages: 1, 4, 16, 32 and 52 weeks old. In addition, to minimise potential batch effect confounding, ages 
were mixed on plates such that each plate contained cells from 3 ages. The exact locations were different between plates to remove the 
potential for plate-spatial effects to also confound analyses downstream. Finally, the sorting took place over 5 days, with cells derived 
from separate mice on each day, leading to 5 replicate mice for each combination of time point and TEC subpopulation.

# Preparing the processed data

To minimise processing and maximise usability, we have provided a single gzip compressed counts matrix after removal of poor-quality cells. 
Borrowing from the `r Biocpkg("MouseGastrulationAtlas")` we also make using of caching in the `r Biocpkg("BiocFileCache")` to avoid having to 
constantly download data for subsequent analyses.

```{r}
library(BiocFileCache)
bfc <- BiocFileCache("SMARTseq_raw", ask=FALSE)
count.path <- bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                      "jmlab/thymus_data/QC_counts.tsv.gz"))
```

These contain the gene counts for cells that pass QC (detailed in manuscript); I have not removed the genes with all zero counts across these 
cells. For these data to be usable we also need the gene IDs - these are provided as a separate table that contains additional information 
such as the chromosome, start and end position and gene length.

```{r}
genes.path <- bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                      "jmlab/thymus_data/Gene_info.tsv"))
```

Both of these data can be loaded in using the standard `read.table` functions.

```{r}
thymus.counts <- read.table(count.path, sep="\t", header=TRUE, stringsAsFactors=FALSE)
gene.info <- read.table(genes.path, sep="\t", header=TRUE, stringsAsFactors=FALSE)
```

Finally, we can download the size factors and other cell-wise meta-data, including sorting day (replicate), sort population, age, cluster 
ID as assigned in the manuscript and plate information. We can also pull in the reduced dimensional representations at this stage.

```{r}
# meta data
meta.path <- bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                     "jmlab/thymus_data/meta_data.tsv.gz"))
meta.data <- read.table(meta.path, sep="\t", header=TRUE, stringsAsFactors=FALSE)
rownames(meta.data) <- meta.data$CellID
meta.data <- meta.data[colnames(thymus.counts), ]
head(meta.data)
```


```{r}
# pca
reds.path <- bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                     "jmlab/thymus_data/reduced_dims.tsv.gz"))
pca.dims <- read.table(reds.path, sep="\t", header=TRUE, stringsAsFactors=FALSE)
rownames(pca.dims) <- pca.dims$CellID
pca.dims <- pca.dims[colnames(thymus.counts), ]
head(pca.dims)
```


```{r}
# size factors
sf.path <- bfcrpath(bfc, file.path("https://content.cruk.cam.ac.uk/",
                                     "jmlab/thymus_data/size_factors.tsv.gz"))
size.factors <- read.table(sf.path, sep="\t", header=TRUE, stringsAsFactors=FALSE)
rownames(size.factors) <- size.factors$CellID
size.factors <- size.factors[colnames(thymus.counts), ]
head(size.factors)
```

We will now put all of these together into a convenient `SingleCellExperiment` object.

```{r}
library(SingleCellExperiment)
thymus.sce <- SingleCellExperiment(assays=list(counts=thymus.counts),
                                   colData=meta.data, rowData=gene.info)

# add the size factors
sizeFactors(thymus.sce) <- size.factors$SizeFactor

reducedDim(thymus.sce, "PCA") <- as.matrix(pca.dims[, paste0("PC", 1:50)])
thymus.sce
```

We are now in the position to save all of these data. We'll do this by breaking up the `SingleCellExperiment` object into smaller, sorting 
day-wise objects. as this will help to increase the speed of downloading. These smaller files are what get uploaded to 
`r Biocpkg("ExperimentHub")`.

```{r}
base <- file.path("MouseThymusAgeing", "SMARTseq", "1.0.0")
dir.create(base, recursive=TRUE, showWarnings=FALSE)
saveRDS(rowData(thymus.sce), file=paste0(base, "/rowdata.rds"))
for(day in unique(thymus.sce$SortDay)){
    sub <- thymus.sce[, thymus.sce$SortDay == day]
    saveRDS(counts(sub), 
        file=paste0(base, "/counts-processed-day", day, ".rds"))
    saveRDS(colData(sub), 
        file=paste0(base, "/coldata-day", day, ".rds"))
    saveRDS(sizeFactors(sub), 
        file=paste0(base, "/sizefac-day", day, ".rds"))
    saveRDS(reducedDims(sub), 
        file=paste0(base, "/reduced-dims-day", day, ".rds"))
}
```


# Session information

```{r}
sessionInfo()
```

---
title: Overview of the MouseThymusAgeing datasets
author: Mike Morgan
date: "November 4, 2020"
output:
  BiocStyle::html_document:
    toc_float: true
vignette: >
  %\VignetteIndexEntry{Available datasets}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
bibliography: thymus.bib
---

```{r, echo=FALSE, results="hide"}
knitr::opts_chunk$set(error=FALSE, warning=FALSE, message=FALSE)
```

# Introduction

The `r Biocpkg("MouseThymusAgeing")` package provides convenient access to the single-cell RNA sequencing (scRNA-seq) datasets from @baran-gale_ageing_2020. The study used single-cell transcriptomic profiling to resolve how the epithelial composition of the mouse thymus 
changes with ageing. The datasets from the paper are provided as count matrices with relevant sample-level and feature-level meta-data. All data 
are provided post-processing and QC. The raw sequencing data can be directly acquired from ArrayExpress using accessions 
[E-MTAB-8560](https://www.ebi.ac.uk/arrayexpress/experiments/E-MTAB-8560/) and [E-MTAB-8737](https://www.ebi.ac.uk/arrayexpress/experiments/E-MTAB-8737/).

# Installation

The package can be installed from Bioconductor. Bioconductor packages can be accessed using the `r CRANpkg("BiocManager")` package.

```{r getPackage, eval=FALSE}
if (!requireNamespace("BiocManager", quietly = TRUE))
    install.packages("BiocManager")
BiocManager::install("MouseThymusAgeing")
```

To use the package, load it in the typical way.

```{r Load, message=FALSE}
library(MouseThymusAgeing)
```

# Processsing Overview

Detailed experimental protocols are available in [the manuscript](https://elifesciences.org/articles/56221) and analytical details are provided 
in the accompanying [GitHub repo](https://github.com/WTSA-Homunculus/Ageing2019).

This data package contains 2 single-cell data sets from the paper. The first details the initial transcriptomic profiling of defined TEC 
populations using the plate-based SMART-seq2 chemistry. These cells were sorted from mice at 1, 4, 16, 32 and 52 weeks of age using the 
following flow cytometry phenotypes:

* mTEClo: Cd45- EpCam+ Ly51- Cd80lo MHCIIlo Dsg3-
* mTEChi: Cd45- EpCam+ Ly51- Cd80hi MHCIIhi Dsg3-
* cTEC: Cd45- EpCam+ Ly51+ Cd80-
* Dsg3+ TEC: Cd45- EpCam+ Ly51- Cd80lo MHCIIlo Dsg3+

In each case cells were sorted from 5 separate mice at each age into a 384 well plate containing lysis buffer, with cells from different ages 
and days block sorted into different areas of each plate to minimise the confounding between batch effects, mouse age and sorted subpopulation. The single-cell libraries were prepared according to the [SMART-seq2 protocol](https://doi.org/10.1038/nprot.2014.006) and sequenced on an Illumina 
NovaSeq 6000.

The computational processing invovled the following steps:

* Read trimming with trimmomatic, prior to alignment to the mm10 genome with STAR v2.5.3a, and read de-duplication using Picard Tools. 
* FeatureCounts was used to count reads on each gene using the Ensembl v95 annotation.
* Poor quality cells were removed based on excess of ERCC92 spiked-in sequences, poor sequencing coverage and low gene-detection.
* Gene counts were normalized using size factors estimated using `computeSumFactors()` function from `r Biocpkg("scran")` [@l._lun_pooling_2016].
* Highly variable genes were identified, and used to subset the log (+1 pseudocount) normalised expression prior to PCA.
* Shared nearest neighbour (SNN) graph building was performed using `r CRANpkg("igraph")` and cells were clustered using the Walktrap community 
detection algorithm [@pons_computing_2005]. Clusters were manually annotated based on inspecting the expression of marker genes.

The second dataset contains cells that were profiling from TEC at 8, 20 and 36 weeks old, derived from a transgenic model system that is also able 
to lineage trace cells that derive from those that express the thymoproteasomal gene, $\beta$-5t. When this gene is expressed it drives 
the expression of a fluorescent reporter gene, ZsGreen (ZsG). The mouse is denoted $\mbox{3xtg}^{\beta5t}$. Each mouse (3 replicates per age) 
first had their transgene induced using doxycycline, and 4 weeks later the TEC were collected by flow cytometry in separate ZsG+ and ZsG- groups. 
Within each of these groups cells were FAC-sorted into mTEC (Cd45+EpCam+MHCII+Ly51-UEA1+) and cTEC (Cd45+EpCam+Ly51+UEA1+) populations. For this 
experiment we made us of recent developments in multiplexing with hashtag oligos (HTO; cell-hashing)[@stoeckius_cell_2018]. Consequently, the 
cells were super-loaded onto  the 10X Genomics Chromium chips before library prep and sequencing on an Illumina NovaSeq 6000.

The computational processing for these data is different to above. Specifically:

* Demultiplexing, read alignment, UMI deduplication and feature counting were all performed using _Cellranger_ v3.1.0.
* Non-empty droplets were called separately using the `emptyDrops()` from the `r Biocpkg("DropletUtils")` [@lun_emptydrops_2019].
* Cells were de-multiplexed into specific samples by assigning each cell to its best-matching hashtag oligo using the approach by 
[@stoeckius_cell_2018] - this was also able to identify multiplet cells containing multiple HTOs.
* Cells were filtered based on low sequencing coverage and high deviation of mitochondrial content from the population median.
* Size factors were estimated as above using `computeSumFactors()` function from `r Biocpkg("scran")` [@l._lun_pooling_2016], and used for 
normalization with a `log(X + 1)` transformation.
* A SNN-graph was then built using `r CRANpkg("igraph")` as above, and cell were also clustered using Walktrap community detection algorithm 
[@pons_computing_2005]. These clusters were annotated with concordant labels from the above data set. The exception being that many more clusters 
were identified, and thus each cluster was suffixed with a number to uniquely identify them.

# Package data format

The SMART-seq2 data is stored in subsets according to the sorting day (numbered 1-5). For the droplet data, the data can be accessed according 
to the specific multiplexed samples (6 in total). For the SMART-seq2 the exported object `SMARTseqMetadata` provides the relevant metadata
information for each sorting day, the equivalent object `DropletMetadata` contains the relevant information for each separate sample. Specific 
descriptions of each column can be accessed using `?SMARTseqMetadata` and `?DropletMetadata`.

```{r}
head(SMARTseqMetadata, n = 5)
```

All of the data access functions allow you to select the particular samples or sorting days that you would like to access for the relevant data 
set. By loading only the samples or sorting days that you are interested in for your particular analysis, you will save time when downloading 
and loading the data, and also reduce memory consumption on your machine.

Droplet single-cell experiments tend to be much larger owing to the ability to encapsulate and process many more cells than in either 96- or 384-well 
plates. The droplet scRNA-seq made use of hashtag oligonucleotides to multiplex samples, allowing for replicated experimental design without 
breaking the bank.

```{r}
head(DropletMetadata, n = 5)
```


## Data access

Package data are provided as `SingleCellExperiment` objects, an extension of the Bioconductor `SummarizedExperiment` object for high-throughput 
omics experiment data. `SingleCellExperiment` object uses memory-efficient storage and sparse matrices to store the single-cell experiment data, 
whilst allowing the layering of additional feature- and cell-wise meta-data to facilitate single-cell analyses.  This section will detail how 
to access and interact with these objects from the `MouseThymusAgeing` package.

```{r, message=FALSE}
smart.sce <- MouseSMARTseqData(samples="day2")
smart.sce
```

The gene counts are stored in the `assays(sce, "counts")` slot, which can be accessed using the convenience function `counts`. The gene counts are 
stored in a memory efficient sparse matrix class from the `r CRANpkg("Matrix")` package.

```{r, message=FALSE}
head(counts(smart.sce)[, 1:10])
```

The normalisation factors per cell can be accessed using the `sizeFactors()` function.

```{r}
head(sizeFactors((smart.sce)))
```

These are used to normalise the data. To generate single-cell expression values on a log-normal scale, we can apply the `logNormCounts` from the 
`r Biocpkg("scuttle")` package. This will add the `logcounts` entry to the `assays` slot in our object.

```{r, message=FALSE}
library(scuttle)
smart.sce <- logNormCounts(smart.sce)
```

With these normalised counts we can perform our standard down-stream analytical tasks, such as identifying highly variable genes, projecting 
cells into a reduced dimensional space and clustering using a nearest-neighbour graph.  You can further inspect the cell-wise meta-data attached 
to each dataset, stored in the `colData` for each `r Biocpkg("SingleCellExperiment")` object.

```{r, message=FALSE}
head(colData(smart.sce))
```

Details of what information is stored can be found in the documentation using `?DropletMetadata` and `?SMARTseqMetada`. In each object we also 
have the pre-computed reduced dimensions that can be accessed through the `reducedDim(<sce>, "PCA")` slot.





# Session Information

```{r}
sessionInfo()
```

# References

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MouseDropletData.R
\name{MouseDropletData}
\alias{MouseDropletData}
\title{Mouse ageing thymus droplet single-cell RNA-sequencing data}
\usage{
MouseDropletData(samples = NULL)
}
\arguments{
\item{samples}{Integer or character vector specifying the samples for which data should be obtained.
If \code{NULL} (default), data are returned for all (6) samples.}
}
\value{
A \linkS4class{SingleCellExperiment} is returned containing processed data from selected samples.

List elements are named after the corresponding sample.
}
\description{
Obtain the processed counts for the mouse ageing thymus droplet scRNA-seq data set.
}
\details{
This function downloads the data for the mouse ageing thymus droplet scRNA-seq
data from Baran-Gale et al. (2020).

The dataset contains 6 10X Genomics samples. The available samples are:
\code{ZsG_1stRun1, ZsG_1stRun2, ZsG_2ndRun1, ZsG_2ndRun2, ZsG_3rdRun1, ZsG_3rdRun2}.


In the data, cell-containing libraries have already been identified in each sample
using the \code{emptyDrops} function from \pkg{DropletUtils}.
The count matrix contains the raw count vectors for the cells called from all samples in this manner.
Size factors were computed using the \code{computeSumFactors} function from \pkg{scran}.
The column metadata for called cells contains:
\describe{
\item{\code{CellID}:}{Character, unique cell identifier across all samples.}
\item{\code{SampID}:}{Character, Short unique identified for the experimental sample.}
\item{\code{Class}:}{Character, Either Singlet or Multiplet Identifies cells called as a multiplet from hash-tag demultiplexing.}
\item{\code{HTO}:}{Character, Hashtag oligo (HTO) character identifier, used for multiplexing experimental samples.}
\item{\code{Age}:}{Character, Age of mouse at the time of doxycycline treatment. Age at time of data acquisition is +4weeks.}
\item{\code{SortType}:}{Character, Flow cytometry sorting group, either ZsGreen+ (ZsGp) or ZsGreen- (ZsGn).}
\item{\code{Cluster}:}{Integer, Cluster to which cells were assigned based on using the Walktrap community detection algorithm on a k-NN graph.}
\item{\code{ClusterAnnot}:}{Character, Annotation assigned to cluster.}
\item{\code{SizeFactor}:}{Numeric, Estimated normalized factor across all cells and experimental samples.}
}
Reduced dimension representations of the data are also available in the \code{reducedDims} slot of the SingleCellExperiment object.
The \code{SingleCellExperiment} object has row metadata that contains the Ensembl ID \code{ensembl_gene_id} and Gene
symbols \code{external_gene_name} for each gene, as well as gene chromosome, strand and both start and end positions.
}
\examples{
drop.data <- MouseDropletData(samples = "ZsG_1stRun1")
drop.data

}
\references{
Baran-Gale J, Morgan MD, et al. (2020)
Ageing compromises mouse thymus function and remodels epithelial cell differentiation
\emph{eLife} 9:e56221.
}
\author{
Mike Morgan, based on original code by Aaron Lun & Jonathan Griffiths

Mike Morgan
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SMARTseqMetadata.R
\docType{data}
\name{SMARTseqMetadata}
\alias{SMARTseqMetadata}
\title{Sample metadata from the Baran-Gale et al. ageing mouse thymus}
\format{
A data frame containing information for each replicate sample

The object contains:
\describe{
\item{\code{sample}:}{Character, day<1:5>.}
\item{\code{Age}:}{Character, age of mouse cells acquired from.}
\item{\code{Gender}:}{Character, gender of mouse - all female.}
\item{\code{ncells}:}{Integer, number of cells (post-QC) per sample.}
}
}
\usage{
SMARTseqMetadata
}
\description{
A data frame containing mouse age and sort-type information for the
SMARTseq experiment data sets
}
\examples{
head(SMARTseqMetadata)

}
\references{
Baran-Gale J, Morgan MD, et al. (2020)
Ageing compromises mouse thymus function and remodels epithelial cell
differentiation \emph{eLife} 9:e56221.
}
\author{
Mike Morgan
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MouseSMARTseqData.R
\name{MouseSMARTseqData}
\alias{MouseSMARTseqData}
\title{Mouse ageing thymus SMART-seq2 single-cell RNA-sequencing data}
\usage{
MouseSMARTseqData(samples = NULL)
}
\arguments{
\item{samples}{Integer or character vector specifying the samples for which data should be obtained.
If \code{NULL} (default), data are returned for all (5) samples.}
}
\value{
A \linkS4class{SingleCellExperiment} is returned containing processed data from selected samples.

List elements are named after the corresponding sample.
}
\description{
Obtain the processed counts for the mouse ageing thymus SMART-seq2 scRNA-seq data set.
}
\details{
This function downloads the data for the mouse ageing thymus droplet scRNA-seq
data from Baran-Gale et al. (2020).

The dataset contains 5 different SMART-seq2 samples, split by the day of acquisition. The available samples are:
\code{day1, day2, day3, day4, day5}.

In the data, poor-quality cells have already been removed based on insufficient sequencing depth, high mitochondrial
content, excessive proportion of expression from ERCC spike-in and ribosomal genes. Exact details can be found in the
methods section of Baran-Gale et al. (2020).

The count matrix contains the raw count vectors for the cells that pass QC.
Size factors were computed using the \code{computeSumFactors} function from \pkg{scran}.
The column metadata for called cells contains:
\describe{
\item{\code{CellID}:}{Character, unique cell identifier across all samples.}
\item{\code{ClusterID}:}{Numeric, The cluster to which cells were assigned based on community detection on a shared-NN grpah.}
\item{\code{Position}:}{Character, Plate position of the index-sorted cell (384 well plate format).}
\item{\code{PlateID}:}{Character, A unique ID for the 384-well plate into which each cell was index-sorted.}
\item{\code{Column}:}{Integer, A value from 1-24 corresponding to the plate column.}
\item{\code{Row}:}{Character, A value from A-P corresponding to the plate row.}
\item{\code{SortType}:}{Character, Flow cytometry sorting group, mTEClo, mTEChi, gmTEC or cTEC.}
\item{\code{SortDay}:}{Integer, Day on which cells were sorted - corresponds to the sample IDs for downloading data and replicate.}
\item{\code{Age}:}{Character, Mouse age at the time of data acquisition.}
\item{\code{SubType}:}{Character, Annotation assigned to clusters.}
\item{\code{SizeFactor}:}{Numeric, Estimated normalized factor across all cells and experimental samples.}
}
Reduced dimension representations of the data are also available in the \code{reducedDims} slot of the SingleCellExperiment object.
The \code{SingleCellExperiment} object has row metadata that contains the Ensembl ID \code{ensembl_gene_id} and Gene
symbols \code{external_gene_name} for each gene, as well as gene chromosome, strand and both start and end positions.
}
\examples{
smart.data <- MouseSMARTseqData(samples = "day1")
smart.data

}
\references{
Baran-Gale J, Morgan MD, et al. (2020)
Ageing compromises mouse thymus function and remodels epithelial cell differentiation
\emph{eLife} 9:e56221.
}
\author{
Mike Morgan, based on original code by Aaron Lun & Jonathan Griffiths

Mike Morgan
}
